@@ -1,24 +1,22 @@
 package HTML::FormFu::Element::Fieldset;
 
-use strict;
-use base 'HTML::FormFu::Element::Block';
-use MRO::Compat;
-use mro 'c3';
+use Moose;
+extends 'HTML::FormFu::Element::Block';
 
 __PACKAGE__->mk_output_accessors(qw( legend ));
 
-sub new {
-    my $self = shift->next::method(@_);
+after BUILD => sub {
+    my $self = shift;
 
     $self->tag('fieldset');
 
-    return $self;
-}
+    return;
+};
 
 sub render_data_non_recursive {
     my ( $self, $args ) = @_;
 
-    my $render = $self->next::method( {
+    my $render = $self->SUPER::render_data_non_recursive( {
             legend => $self->legend,
             $args ? %$args : (),
         } );
@@ -26,6 +24,8 @@ sub render_data_non_recursive {
     return $render;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
